@@ -11,21 +11,8 @@ from abc import abstractmethod
 from sklearn.base import BaseEstimator
 from sklearn.exceptions import NotFittedError
 
-from ..logging import Logger
-
 
 class Base:
-    def __getstate__(self):
-        d = self.__dict__.copy()
-        del d["_logger"]
-        del d["_class_logger"]
-        return d
-
-    def __setstate__(self, d):
-        self.__dict__.update(d)
-        self._class_logger = Logger(__name__)
-        self._logger = self._class_logger.logger
-
     def _check_is_fitted(self):
         if not self._is_fitted:
             raise NotFittedError("This {} instance is not fitted yet. Call "
