@@ -49,9 +49,10 @@ class BinningCP:
     def build_model(self, divergence, n_nonevent, n_event, trend_change):
         # Parameters
         M = int(1e6)
-        D, V, pvalue_violation_indices = model_data(divergence, n_nonevent,
-                                                    n_event, self.max_pvalue,
-                                                    self.max_pvalue_policy, M)
+        (D, V, pvalue_violation_indices,
+         min_diff_violation_indices) = model_data(
+            divergence, n_nonevent, n_event, self.max_pvalue,
+            self.max_pvalue_policy, self.min_event_rate_diff, M)
 
         n = len(n_nonevent)
         n_records = n_nonevent + n_event
@@ -159,6 +160,9 @@ class BinningCP:
         # Constraint: max-pvalue
         self.add_max_pvalue_constraint(model, x, pvalue_violation_indices)
 
+        # Constraint: min diff
+        self.add_min_diff_constraint(model, x, min_diff_violation_indices)
+
         # Constraint: fixed splits
         self.add_constraint_fixed_splits(model, n, x)
 
@@ -169,8 +173,10 @@ class BinningCP:
     def build_model_scenarios(self, n_nonevent, n_event, w):
         # Parameters
         M = int(1e6)
-        D, V, pvalue_violation_indices = multiclass_model_data(
-            n_nonevent, n_event, self.max_pvalue, self.max_pvalue_policy, M)
+        (D, V, pvalue_violation_indices,
+         min_diff_violation_indices) = multiclass_model_data(
+            n_nonevent, n_event, self.max_pvalue, self.max_pvalue_policy,
+            self.min_event_rate_diff, M)
 
         n = len(n_nonevent)
         n_records = n_nonevent + n_event
@@ -240,6 +246,11 @@ class BinningCP:
             self.add_max_pvalue_constraint(model, x,
                                            pvalue_violation_indices[s])
 
+        # Constraint: min diff
+        for s in range(n_scenarios):
+            self.add_min_diff_constraint(model, x,
+                                         min_diff_violation_indices[s])
+
         # Constraint: fixed splits
         self.add_constraint_fixed_splits(model, n, x)
 
@@ -378,7 +389,6 @@ class BinningCP:
                         model.Add(bin_size <= self.max_bin_size[s] * x[i, i])
 
     def add_constraint_monotonic_ascending(self, model, n, D, x, M):
-        min_event_rate_diff = int(M * self.min_event_rate_diff)
         for i in range(1, n):
             for z in range(i):
                 model.Add(
@@ -386,8 +396,7 @@ class BinningCP:
                          for j in range(z)]) +
                     D[z][z] * x[z, z] - M - (D[i][i] - M) * x[i, i] -
                     sum([(D[i][j] - D[i][j + 1]) * x[i, j]
-                         for j in range(i)]) +
-                    min_event_rate_diff * (x[i, i] + x[z, z] - 1) <= 0)
+                         for j in range(i)]) <= 0)
 
         # Preprocessing
         if self.min_event_rate_diff == 0:
@@ -399,7 +408,6 @@ class BinningCP:
                             model.Add(x[i+j, i+j] == 0)
 
     def add_constraint_monotonic_descending(self, model, n, D, x, M):
-        min_event_rate_diff = int(M * self.min_event_rate_diff)
         for i in range(1, n):
             for z in range(i):
                 model.Add(
@@ -407,8 +415,7 @@ class BinningCP:
                          for j in range(i)]) + D[i][i] * x[i, i] -
                     M - (D[z][z] - M) * x[z, z] -
                     sum([(D[z][j] - D[z][j+1]) * x[z, j]
-                         for j in range(z)]) +
-                    min_event_rate_diff * (x[i, i] + x[z, z] - 1) <= 0)
+                         for j in range(z)]) <= 0)
 
         # Preprocessing
         if self.min_event_rate_diff == 0:
@@ -484,7 +491,6 @@ class BinningCP:
                     D[i][i] * x[i, i] >= 0)
 
     def add_constraint_monotonic_peak_heuristic(self, model, n, D, x, tc, M):
-        min_event_rate_diff = int(M * self.min_event_rate_diff)
         for i in range(1, tc):
             for z in range(i):
                 model.Add(
@@ -492,8 +498,7 @@ class BinningCP:
                          for j in range(z)]) +
                     D[z][z] * x[z, z] - M - (D[i][i] - M) * x[i, i] -
                     sum([(D[i][j] - D[i][j + 1]) * x[i, j]
-                         for j in range(i)]) +
-                    min_event_rate_diff * (x[i, i] + x[z, z] - 1) <= 0)
+                         for j in range(i)]) <= 0)
 
         # Preprocessing
         if self.min_event_rate_diff == 0:
@@ -511,8 +516,7 @@ class BinningCP:
                          for j in range(i)]) + D[i][i] * x[i, i] -
                     M - (D[z][z] - M) * x[z, z] -
                     sum([(D[z][j] - D[z][j+1]) * x[z, j]
-                         for j in range(z)]) +
-                    min_event_rate_diff * (x[i, i] + x[z, z] - 1) <= 0)
+                         for j in range(z)]) <= 0)
 
         # Preprocessing
         if self.min_event_rate_diff == 0:
@@ -524,7 +528,6 @@ class BinningCP:
                             model.Add(x[i+j, i+j] == 0)
 
     def add_constraint_monotonic_valley_heuristic(self, model, n, D, x, tc, M):
-        min_event_rate_diff = int(M * self.min_event_rate_diff)
         for i in range(1, tc):
             for z in range(i):
                 model.Add(
@@ -532,8 +535,7 @@ class BinningCP:
                          for j in range(i)]) + D[i][i] * x[i, i] -
                     M - (D[z][z] - M) * x[z, z] -
                     sum([(D[z][j] - D[z][j+1]) * x[z, j]
-                         for j in range(z)]) +
-                    min_event_rate_diff * (x[i, i] + x[z, z] - 1) <= 0)
+                         for j in range(z)]) <= 0)
 
         # Preprocessing
         if self.min_event_rate_diff == 0:
@@ -551,8 +553,7 @@ class BinningCP:
                          for j in range(z)]) +
                     D[z][z] * x[z, z] - M - (D[i][i] - M) * x[i, i] -
                     sum([(D[i][j] - D[i][j + 1]) * x[i, j]
-                         for j in range(i)]) +
-                    min_event_rate_diff * (x[i, i] + x[z, z] - 1) <= 0)
+                         for j in range(i)]) <= 0)
 
         # Preprocessing
         if self.min_event_rate_diff == 0:
@@ -568,6 +569,11 @@ class BinningCP:
             model.AddImplication(x[ind1[0], ind1[1]],
                                  x[ind2[0], ind2[1]].Not())
 
+    def add_min_diff_constraint(self, model, x, min_diff_violation_indices):
+        for ind1, ind2 in min_diff_violation_indices:
+            model.AddImplication(x[ind1[0], ind1[1]],
+                                 x[ind2[0], ind2[1]].Not())
+
     def add_constraint_fixed_splits(self, model, n, x):
         if self.user_splits_fixed is not None:
             for i in range(n - 1):
