@@ -114,8 +114,9 @@ class OptimalPWBinning(BasePWBinning):
 
     outlier_detector : str or None, optional (default=None)
         The outlier detection method. Supported methods are "range" to use
-        the interquartile range based method or "zcore" to use the modified
-        Z-score method.
+        the interquartile range based method, "zcore" to use the modified
+        Z-score method or "yquantile" to use the y-axis detector over
+        quantiles.
 
     outlier_params : dict or None, optional (default=None)
         Dictionary of parameters to pass to the outlier detection method.
@@ -142,7 +143,9 @@ class OptimalPWBinning(BasePWBinning):
         <https://github.com/embotech/ecos>`_, `"osqp"
         <https://github.com/oxfordcontrol/osqp>`_, "direct", to choose the
         direct solver, and "auto", to choose the most appropriate solver for
-        the problem.
+        the problem. Version 0.16.1 added support to solvers
+        `"scs" <https://github.com/cvxgrp/scs>`_ and `"highs"
+        <https://github.com/ERGO-Code/HiGHS>`_.
 
     h_epsilon: float (default=1.35)
         The parameter h_epsilon used when ``objective="huber"``, controls the
