@@ -391,7 +391,9 @@ def transform_continuous_target(splits, dtype, x, n_records, sums,
 
     if metric == "mean":
         # Compute mean
-        metric_value = sums / n_records
+        mask = n_records > 0
+        metric_value = np.zeros(len(n_records))
+        metric_value[mask] = sums[mask] / n_records[mask]
         x_transform = np.zeros(x.shape)
     else:
         # Assign corresponding indices or bin intervals
